# - Config file for the BxDecay0 package
# It defines the following variables
#  BxDecay0_VERSION       - BxDecay0 version

#----------------------------------------------------------------------
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#----------------------------------------------------------------------

set(BxDecay0_VERSION 1.1.0)
set(BxDecay0_CXX_STANDARD 17)
set(BxDecay0_WITH_GEANT4_EXTENSION 0)

# 2021-08-30 FM: Policy defined from CMake 3.3 and up to unknown future version
if (CMAKE_VERSION VERSION_GREATER "3.3")
  cmake_policy(SET CMP0057 NEW) # interpret the IN_LIST operator in if()
endif()


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was BxDecay0Config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

####################################################################################

set(_BxDecay0_supported_components Geant4)

set_and_check(BxDecay0_INCLUDE_DIR ${PACKAGE_PREFIX_DIR}/include)

#-----------------------------------------------------------------------
# Handle paths/targets for third party deps here...
#
set(BxDecay0_GSL_VERSION 2.7)
set(GSL_ROOT_DIR $ENV{GSL_FQ_DIR})
find_package(GSL ${BxDecay0_GSL_VERSION} REQUIRED)

#-----------------------------------------------------------------------
# Include the file listing all the imported targets.
# This is installed in the same location as us...
#
if(NOT BxDecay0_TARGETS_LOADED)
  include("${CMAKE_CURRENT_LIST_DIR}/BxDecay0Targets.cmake")
  set(BxDecay0_TARGETS_LOADED 1)
endif()

set(BxDecay0_LIBRARIES BxDecay0::BxDecay0)
if (BxDecay0_WITH_GEANT4_EXTENSION)
  list(APPEND BxDecay0Geant4_LIBRARIES BxDecay0::BxDecay0_Geant4)
endif()

set(BxDecay0_FOUND True)
# Component check
foreach(_requested_comp ${BxDecay0_FIND_COMPONENTS})
  # The following line requires the CMP0057 policy set to NEW:
  if (NOT _requested_comp IN_LIST _BxDecay0_supported_components)
    set(BxDecay0_FOUND False)
    set(BxDecay0_NOT_FOUND_MESSAGE "Unsupported component: ${_requested_comp}")
  endif()
  if ("${_requested_comp}" STREQUAL "Geant4")
    if (NOT BxDecay0_WITH_GEANT4_EXTENSION)
      set(BxDecay0_Geant4_FOUND False)      
      set(BxDecay0_FOUND False)
      set(BxDecay0_NOT_FOUND_MESSAGE "Requested component ${_requested_comp} is not available")
    else()
      set(BxDecay0_Geant4_FOUND True)      
    endif()
  endif()
  
endforeach()

# - end
